Coverage for tictactoe/config: 100%

# Coverage for tictactoe/config : 100%

## 8 statements 8 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 | import logging import os import configparser config = configparser.RawConfigParser() HERE = os.path.dirname(__file__) configfiles = [ '/etc/tictactoe.cfg', # staging/live os.path.join(HERE, 'tictactoe.default.cfg'), # default config os.path.join(HERE, 'tictactoe.cfg'), # per-environment config ] files_read = config.read(configfiles) logging.debug('config files read: %s' % files_read)